import {
  IonContent,
  IonHeader,
  IonPage,
  IonTitle,
  IonToast,
  IonToolbar,
} from "@ionic/react";
import { alertCircleOutline } from "ionicons/icons";
import useSWR from "swr";
import DropdownComponent from "../components/DropdownComponent";
import TopicList from "../components/TopicList";
import { fetcher } from "../lib/api";
import { Topic } from "../types";

const AdviceListPage: React.FC = () => {
  const { data, error } = useSWR<Topic[]>(
    "/api/getTopicList?type=advice",
    fetcher
  );
  const isLoading = !data && !error;

  return (
    <IonPage>
      <IonHeader>
        <IonToolbar>
          <IonTitle>Advice</IonTitle>
        </IonToolbar>
      </IonHeader>
      <IonContent fullscreen>
        <IonHeader collapse="condense">
          <IonToolbar>
            <IonTitle size="large">Advice</IonTitle>
          </IonToolbar>
        </IonHeader>
        <DropdownComponent name="Parentesco">
          <TopicList
            loading={isLoading}
            topics={data ? (data as Topic[]) : []}
          />
        </DropdownComponent>
        <IonToast
          icon={alertCircleOutline}
          color="danger"
          isOpen={error !== undefined}
          message="Failed to load items."
          duration={1500}
        />
      </IonContent>
    </IonPage>
  );
};

export default AdviceListPage;
